@@ -10,10 +10,10 @@ will be aborted and the original exception will be re-raised.
 """
 
 import logging
-from typing import Iterable, List, Union
+from typing import Iterable, List, Tuple, Union
 
 from hammurabi.config import config
-from hammurabi.exceptions import AbortLawError
+from hammurabi.exceptions import AbortLawError, PreconditionFailedError
 from hammurabi.helpers import full_strip
 from hammurabi.mixins import GitMixin
 from hammurabi.rules.base import Precondition, Rule
@@ -63,11 +63,55 @@ class Law(GitMixin):
         self.name = name.strip()
         self.description = full_strip(description)
         self.rules: Iterable[Rule] = tuple()
-        self.failed_rules: Iterable[Rule] = tuple()
+        self._failed_rules: Union[Tuple[()], Tuple[Rule]] = ()
 
         for rule in rules:
             self.rules += (rule,)
 
+    @property
+    def passed_rules(self) -> Tuple[Rule, ...]:
+        """
+        Return the rules which did modifications and not failed.
+
+        :return: Return the passed rules
+        :rtype: Tuple[Rule, ...]
+        """
+
+        return tuple(r for r in self.rules if r.made_changes)
+
+    @property
+    def failed_rules(self) -> Union[Tuple[()], Tuple[Rule]]:
+        """
+        Return the rules which did modifications and failed.
+
+        :return: Return the failed rules
+        :rtype: Union[Tuple[()], Tuple[Rule]]
+        """
+
+        return self._failed_rules
+
+    @property
+    def skipped_rules(self) -> Tuple[Rule, ...]:
+        """
+        Return the rules which neither modified the code nor failed.
+
+        :return: Return the skipped rules
+        :rtype: Tuple[Rule, ...]
+        """
+
+        def is_skipped(rule) -> bool:
+            """
+            Return the evaluation if the rule is skipped or not.
+
+            :return: Evaluation if the rule is skipped
+            :rtype: bool
+            """
+            not_passed = rule not in self.passed_rules
+            not_failed = rule not in self.failed_rules
+            return not_passed and not_failed
+
+        return tuple(r for r in self.rules if is_skipped(r))
+
     @property
     def documentation(self) -> str:
         """
@@ -100,8 +144,8 @@ class Law(GitMixin):
 
     def commit(self):
         """
-        Commit the changes made by registered rules
-        and add a meaningful commit message.
+        Commit the changes made by registered rules and add a
+        meaningful commit message.
 
         Example commit message:
 
@@ -120,7 +164,7 @@ class Law(GitMixin):
         rules_commit_message = "\n".join(rules)
 
         if not rules:
-            logging.warning('No changes made by "%s"', self.name)
+            logging.info('No changes made by "%s"', self.name)
             return
 
         logging.debug('Committing changes made by "%s"', self.name)
@@ -141,11 +185,19 @@ class Law(GitMixin):
 
         try:
             rule.execute()
+        except PreconditionFailedError:
+            logging.warning(
+                'Cancelling execution of "%s", the prerequisites are not fulfilled',
+                rule.name,
+            )
         except Exception as exc:  # pylint: disable=broad-except
             logging.error('Execution of "%s" is aborted: %s', rule.name, str(exc))
 
-            for chain in rule.get_rule_chain(rule):
-                logging.warning('Due to errors "%s" is aborted', chain.name)
+            chained_rules = filter(
+                lambda r: isinstance(r, Rule), rule.get_rule_chain(rule)
+            )
+            for chain in chained_rules:
+                logging.error('Due to errors "%s" is aborted', chain.name)
 
             raise AbortLawError(str(exc)) from exc
 
@@ -173,7 +225,7 @@ class Law(GitMixin):
                 self.__execute_rule(rule)
             except AbortLawError as exc:
                 logging.error(str(exc))
-                self.failed_rules += (rule,)
+                self._failed_rules += (rule,)
 
                 if config.settings.rule_can_abort:
                     raise exc
@@ -182,5 +234,5 @@ class Law(GitMixin):
         # scenarios when the rules will be populated later. Hence we need to
         # make sure we are not wasting time on trying to commit if the law did
         # not get any rule at the end.
-        if self.rules:
+        if self.passed_rules:
             self.commit()
