@@ -254,8 +254,7 @@ class SectionRenamed(SingleConfigFileRule):
         this point, because if other rules depending on the rename they will fail
         otherwise.
 
-        :raises: ``LookupError`` raised if no section can be renamed or both the
-                 new and old sections are in the config file
+        :raises: ``LookupError`` if we can not decide or can not find what should be renamed
         :return: Return the input path as an output
         :rtype: Path
         """
@@ -263,15 +262,15 @@ class SectionRenamed(SingleConfigFileRule):
         has_old_section = self.updater.has_section(self.section)
         has_new_section = self.updater.has_section(self.new_name)
 
-        if not has_old_section:
-            raise LookupError(f'No matching section for "{self.section}"')
-
         if has_old_section and has_new_section:
             raise LookupError(f'Both "{self.section}" and "{self.new_name}" set')
 
         if has_new_section:
             return self.param
 
+        if not has_old_section:
+            raise LookupError(f'No matching section for "{self.section}"')
+
         logging.debug('Renaming "%s" to "%s"', self.section, self.new_name)
         self.updater[self.section].name = self.new_name
 
@@ -470,7 +469,8 @@ class OptionRenamed(SingleConfigFileRule):
         The execution must be stopped at this point, because if dependant rules
         will fail otherwise.
 
-        :raises: ``LookupError`` raised if no section can be renamed
+        :raises: ``LookupError`` raised if no section found or both the old and new
+                 option names are found
         :return: Return the input path as an output
         :rtype: Path
         """
@@ -478,8 +478,17 @@ class OptionRenamed(SingleConfigFileRule):
         if not self.updater.has_section(self.section):
             raise LookupError(f'No matching section for "{self.section}"')
 
-        if not self.updater.has_option(self.section, self.option):
-            raise LookupError(f'No matching option for "{self.option}"')
+        has_old_option = self.updater[self.section].get(self.option)
+        has_new_option = self.updater[self.section].get(self.new_name)
+
+        if has_old_option and has_new_option:
+            raise LookupError(f'Both "{self.option}" and "{self.new_name}" set')
+
+        if has_new_option:
+            return self.param
+
+        if not has_old_option:
+            raise LookupError(f'No matching option for "{self.section}"')
 
         logging.debug(
             'Replacing option "%s" with "%s"', str(self.option), self.new_name
